summaryrefslogtreecommitdiff
path: root/global.c
diff options
context:
space:
mode:
authorrpj <rpj>2005-03-16 01:33:20 +0000
committerrpj <rpj>2005-03-16 01:33:20 +0000
commit37f6fe772e5779120d2ee372c5d51ff60b6801dc (patch)
treeb611e6b1c26e36a32e761962ab6693b02744c784 /global.c
parent3d32060783bcaf10f38ff6eef6fcf5711bfeada4 (diff)
Diffstat (limited to 'global.c')
-rw-r--r--global.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/global.c b/global.c
index 59cb56f..8c92a18 100644
--- a/global.c
+++ b/global.c
@@ -108,9 +108,13 @@ CRITICAL_SECTION ptw32_spinlock_test_init_lock;
CRITICAL_SECTION ptw32_cond_list_lock;
/*
* Global lock to serialise once_control event management.
*/
-CRITICAL_SECTION ptw32_once_event_lock;
+ptw32_once_control_t ptw32_once_control =
+ {
+ PTHREAD_COND_INITIALIZER,
+ PTHREAD_MUTEX_INITIALIZER
+ };
#ifdef _UWIN
/*
@@ -108,9 +108,13 @@ CRITICAL_SECTION ptw32_spinlock_test_init_lock;
CRITICAL_SECTION ptw32_cond_list_lock;
/*
- * Global lock to serialise once_control event management.
+ * Global condition variable and mutex for once_control management.
*/